@@ -13,7 +13,7 @@ from music.utils import (
 logger = logging.getLogger(__name__)
 
 
-def process_audioscrobbler_tsv_file(file_path, user_tz=None):
+def process_audioscrobbler_tsv_file(file_path, user_id, user_tz=None):
     """Takes a path to a file of TSV data and imports it as past scrobbles"""
     new_scrobbles = []
     if not user_tz:
@@ -49,12 +49,13 @@ def process_audioscrobbler_tsv_file(file_path, user_tz=None):
             )
 
             timestamp = (
-                datetime.fromtimestamp(int(row[6]))
+                datetime.utcfromtimestamp(int(row[6]))
                 .replace(tzinfo=user_tz)
                 .astimezone(pytz.utc)
             )
 
             new_scrobble = Scrobble(
+                user_id=user_id,
                 timestamp=timestamp,
                 source=source,
                 source_id=source_id,
@@ -77,20 +78,3 @@ def process_audioscrobbler_tsv_file(file_path, user_tz=None):
             extra={'created_scrobbles': created},
         )
         return created
-
-
-def undo_audioscrobbler_tsv_import(process_log, dryrun=True):
-    """Accepts the log from a TSV import and removes the scrobbles"""
-    if not process_log:
-        logger.warning("No lines in process log found to undo")
-        return
-
-    for line in process_log.split('\n'):
-        scrobble_id = line.split("\t")[0]
-        scrobble = Scrobble.objects.filter(id=scrobble_id).first()
-        if not scrobble:
-            logger.warning(f"Could not find scrobble {scrobble_id} to undo")
-            continue
-        logger.info(f"Removing scrobble {scrobble_id}")
-        if not dryrun:
-            scrobble.delete()
